%%% Created by Amin Rahmani, Ph.D., P.E. - July 14, 2019
%%% Copyright  2019 Amin Rahmani. All rights reserved.

clc;
clear all;
close all;

%%%% Input Data
%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%
load 'disppile_above_ground.out'
load 'disppile_below_ground.out'
load 'pileforcesGlob_above_ground.out'
load 'pileforcesGlob_below_ground.out'
load 'Soilreaction_left.out'
load 'Soilreaction_right.out'

%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%
                                   
LP=50.0;              %% User-defined - Total length of pile        
LP_emb=50.0; 		    %% User-defined - Embedded length of pile considered in the opensees model       
zSize = 2.0;        %% User-defined - Depth increment used in the OpenSees model
Num_Steps = 500;    %% User-defined - Number of analysis steps used in the OpenSees model

%%%% Define Depth Vector
if floor(LP_emb/zSize) == LP_emb/zSize 
	numZele_emb = LP_emb/zSize;          
else 
    numZele_emb = floor(LP_emb/zSize)+1;         
end

if LP_emb == LP 
	numZele_above_grade=0;        
else
    if floor((LP-LP_emb)/zSize) == (LP-LP_emb)/zSize
	     numZele_above_grade = floor((LP-LP_emb)/zSize);          
    else 
	     numZele_above_grade = floor((LP-LP_emb)/zSize)+1;          
    end
end
     

for k=1:(numZele_emb+1)

      if floor(LP_emb/zSize) == LP_emb/zSize
         depth(numZele_above_grade+k) = (k-1)*zSize;
      else   
         if k <= numZele_emb
             depth(numZele_above_grade+k) = (k-1)*zSize;
         else 
             depth(numZele_above_grade+k) = LP_emb;
         end
      end
      
end

	
if numZele_above_grade == 0
    %Do nothing
else
    
    for k=1:numZele_above_grade  

      if floor((LP-LP_emb)/zSize) == (LP-LP_emb)/zSize
         depth(numZele_above_grade+1-k) = -k*zSize;
      else  
         if k <= numZele_above_grade-1
             depth(numZele_above_grade+1-k) = -k*zSize;
         else 
             depth(numZele_above_grade+1-k) = -(LP-LP_emb);
         end
      end
    end
end


%%%% Define Moment, Shear and Displacement Vectors

%%% Finding force/disp for embedded pile elements
for k=1:(numZele_emb)

    Moment(numZele_above_grade+k) = pileforcesGlob_below_ground(Num_Steps,6*(2*k-1))*12/1000;
    Shear(numZele_above_grade+k)  = pileforcesGlob_below_ground(Num_Steps,6*(2*k-1)-4)/1000;
    displacement(numZele_above_grade+k)=disppile_below_ground (Num_Steps,6*k-4)*12;

end

%%% Finding force/disp at the pile tip
k=numZele_emb;
Moment(numZele_above_grade+1+k) = -pileforcesGlob_below_ground(Num_Steps,6*(2*k))*12/1000;
Shear(numZele_above_grade+1+k)  = -pileforcesGlob_below_ground(Num_Steps,6*(2*k)-4)/1000;
displacement(numZele_above_grade+1+k)=disppile_below_ground (Num_Steps,6*k-4)*12;


%%% Finding force/disp for pile elements above grade
for k=numZele_above_grade:-1:1

    Moment(numZele_above_grade+1-k) = pileforcesGlob_above_ground(Num_Steps,6*(2*k))*12/1000;
    Shear(numZele_above_grade+1-k)  = pileforcesGlob_above_ground(Num_Steps,6*(2*k)-4)/1000;
    displacement(numZele_above_grade+1-k)=disppile_above_ground (Num_Steps,6*k-4)*12;
end


%%%% Define Soil Reaction Vectors

if floor(LP_emb/zSize) == LP_emb/zSize 
    
    Num_Springs =numZele_emb+1; 
else 	
    
    Num_Springs =numZele_emb; 
end

%% Depth Vector for Soil Pressure
for k=1:Num_Springs
    
    if floor(LP_emb/zSize) == LP_emb/zSize
        depth_2(numZele_above_grade+k) = (k-1)*zSize;    
    else
       if k ~= Num_Springs
           depth_2(numZele_above_grade+k) = (k-1)*zSize; 
       else
           depth_2(numZele_above_grade+k) = LP_emb;
       end
    end
           
end
	
if numZele_above_grade == 0
    %Do nothing
else
    
    for k=1:numZele_above_grade  

      if floor((LP-LP_emb)/zSize) == (LP-LP_emb)/zSize
         depth_2(numZele_above_grade+1-k) = -k*zSize;
      else  
         if k <= numZele_above_grade-1
             depth_2(numZele_above_grade+1-k) = -k*zSize;
         else 
             depth_2(numZele_above_grade+1-k) = -(LP-LP_emb);
         end
      end
    end
end

%%% Soil Reaction Vector
Soilreaction=zeros(1,Num_Springs+numZele_above_grade);

for k=1:Num_Springs
    
    m = k + numZele_above_grade;
    if k ~= Num_Springs
        Soilreaction(m)=-(Soilreaction_left(Num_Steps,6*(k-1)+2)+Soilreaction_right(Num_Steps,6*(k-1)+2))/(zSize*12);
    else
        % Soil reaction at the closest spring to the pile tip
        if floor(LP_emb/zSize) == LP_emb/zSize
             Soilreaction(m)=-(Soilreaction_left(Num_Steps,6*(k-1)+2)+Soilreaction_right(Num_Steps,6*(k-1)+2))/(zSize/2*12);
        else 
            Soilreaction(m)=-(Soilreaction_left(Num_Steps,6*(k-1)+2)+Soilreaction_right(Num_Steps,6*(k-1)+2))/((zSize/2+(LP_emb-(Num_Springs-1)*zSize))*12);
        end
    end
    
end
    
%%%% Plot the Figures

set(gcf, 'Units', 'centimeters');
afFigurePosition = [1 1 45 35 ]; % [pos_x pos_y width_x width_y]
set(gcf, 'Position', afFigurePosition)

h1=subplot(1,8,[1 2]);
plot(displacement,depth,'b-', 'linewidth', 3);
xlabel('Displacement (inch)','FontSize',16)
ylabel('Depth below ground surface (ft)','FontSize',16)
set(gca,'Ydir','reverse')
set(gca, 'XAxisLocation', 'top')
set(gca,'fontsize',14,'linewidth',2)
%%%%%%%           x, y, width, height
h1_pos = get(h1,'Position'); %get the position data for sublot1.
set(h1,'Position',[h1_pos(1)-0.2*h1_pos(3) h1_pos(2) h1_pos(3) h1_pos(4)]) %using position of subplot1.
legend('OpenSees', 'LPile', 'location', 'southeast' );
grid on

h2=subplot(1,8,[3 4]);
plot(Moment,depth,'b-', 'linewidth', 3);
xlabel('Bending Moment (kips.inch)','FontSize',16)
%ylabel('Depth below ground surface (ft)','FontSize',14)
set(gca,'Ydir','reverse')
set(gca, 'XAxisLocation', 'top')
set(gca,'fontsize',14,'linewidth',2)
h2_pos=get(h2,'Position');
%%%%%%%           x, y, width, height
set(h2,'Position',[h1_pos(1)+h1_pos(3)+0.1*h1_pos(3) h1_pos(2) h1_pos(3) h1_pos(4)]) %using position of subplot1.
grid on

h3=subplot(1,8,[5 6]);
plot(Shear,depth,'b-', 'linewidth', 3);
xlabel('Shear (kips)','FontSize',16)
%ylabel('Depth below ground surface (ft)','FontSize',14)
set(gca,'Ydir','reverse')
set(gca, 'XAxisLocation', 'top')
set(gca,'fontsize',14,'linewidth',2)
h3_pos=get(h3,'Position');
%%%%%%%           x, y, width, height
set(h3,'Position',[h2_pos(1)+h2_pos(3)+.25*h1_pos(3) h2_pos(2) h2_pos(3) h2_pos(4)]) %using position of subplot2.
grid on

h4=subplot(1,8,[7 8]);
plot(Soilreaction,depth_2,'b-', 'linewidth', 3);
xlabel('Mobilized Soil Reaction (lb/inch)','FontSize',16)
%ylabel('Depth below ground surface (ft)','FontSize',14)
set(gca,'Ydir','reverse')
set(gca, 'XAxisLocation', 'top')
set(gca,'fontsize',14,'linewidth',2)
h4_pos=get(h4,'Position');
%%%%%%%           x, y, width, height
set(h4,'Position',[h3_pos(1)+h3_pos(3)+.4*h3_pos(3) h3_pos(2) h3_pos(3) h3_pos(4)]) %using position of subplot3. 
grid on

%%%%%%%% Optional
%%%set(gca,'XTick',[0.0 0.5 1 1.5 2 2.5 3 3.5 4]);
%%%set(gca,'YTick',[0.0 0.5 1 1.5 2 ]);
%%%text(0.015, 5.5, 'TEXT', 'Color', 'k', 'Rotation', 0,'FontSize',18);

%%%% Priniting the figure in a "png for
hgexport(gcf, 'DispMomShr_Graph.png', hgexport('factorystyle'), 'Format', 'png');
